basicSet: Basic Features

View source: R/basicSet.R

basicSetR Documentation

Basic Features

Description

Simple features as inputs to the DICE model

Usage

basicSet(text)

Arguments

text

character A vector of texts, each of which will be tallied for DICE features.

Details

The DICE models use, as features, linear and quadratic terms for sentiment, emotion, and word count.

Value

a data.frame of feature scores for the pre-trained models.


DICEM documentation built on Sept. 12, 2024, 7:42 a.m.