diceNGrams: Pre-trained advice concreteness features

diceNGramsR Documentation

Pre-trained advice concreteness features

Description

For internal use only. This dataset demonstrates the ngram features that are used for the pre-trained models.

Usage

diceNGrams

Format

A (truncated) matrix of ngram feature counts for alignment to the pre-trained glmnet models.

Yeomans et al., (2024). A Natural Language Processing Model for Conflict Expression in Conversation


DICEM documentation built on Sept. 12, 2024, 7:42 a.m.