| basicSet | R Documentation |
Simple features as inputs to the DICE model
basicSet(text)
text |
character A vector of texts, each of which will be tallied for DICE features. |
The DICE models use, as features, linear and quadratic terms for sentiment, emotion, and word count.
a data.frame of feature scores for the pre-trained models.
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.