| diceNGrams | R Documentation |
For internal use only. This dataset demonstrates the ngram features that are used for the pre-trained models.
diceNGrams
A (truncated) matrix of ngram feature counts for alignment to the pre-trained glmnet models.
Yeomans et al., (2024). A Natural Language Processing Model for Conflict Expression in Conversation
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.